@@ -103,7 +103,7 @@ class Exceptions:
 
 class CloudWatchClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html)
     """
 
@@ -119,7 +119,7 @@ class CloudWatchClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#can_paginate)
         """
 
@@ -127,7 +127,7 @@ class CloudWatchClient(BaseClient):
         """
         Deletes the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.delete_alarms)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.delete_alarms)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#delete_alarms)
         """
 
@@ -137,12 +137,12 @@ class CloudWatchClient(BaseClient):
         Namespace: str,
         MetricName: str,
         Stat: str,
-        Dimensions: Sequence["DimensionTypeDef"] = None
+        Dimensions: Sequence["DimensionTypeDef"] = ...
     ) -> Dict[str, Any]:
         """
         Deletes the specified anomaly detection model from your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.delete_anomaly_detector)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.delete_anomaly_detector)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#delete_anomaly_detector)
         """
 
@@ -150,7 +150,7 @@ class CloudWatchClient(BaseClient):
         """
         Deletes all dashboards that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.delete_dashboards)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.delete_dashboards)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#delete_dashboards)
         """
 
@@ -158,7 +158,7 @@ class CloudWatchClient(BaseClient):
         """
         Permanently deletes the specified Contributor Insights rules.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.delete_insight_rules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.delete_insight_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#delete_insight_rules)
         """
 
@@ -166,46 +166,46 @@ class CloudWatchClient(BaseClient):
         """
         Permanently deletes the metric stream that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.delete_metric_stream)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.delete_metric_stream)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#delete_metric_stream)
         """
 
     def describe_alarm_history(
         self,
         *,
-        AlarmName: str = None,
-        AlarmTypes: Sequence[AlarmTypeType] = None,
-        HistoryItemType: HistoryItemTypeType = None,
-        StartDate: Union[datetime, str] = None,
-        EndDate: Union[datetime, str] = None,
-        MaxRecords: int = None,
-        NextToken: str = None,
-        ScanBy: ScanByType = None
+        AlarmName: str = ...,
+        AlarmTypes: Sequence[AlarmTypeType] = ...,
+        HistoryItemType: HistoryItemTypeType = ...,
+        StartDate: Union[datetime, str] = ...,
+        EndDate: Union[datetime, str] = ...,
+        MaxRecords: int = ...,
+        NextToken: str = ...,
+        ScanBy: ScanByType = ...
     ) -> DescribeAlarmHistoryOutputTypeDef:
         """
         Retrieves the history for the specified alarm.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarm_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarm_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#describe_alarm_history)
         """
 
     def describe_alarms(
         self,
         *,
-        AlarmNames: Sequence[str] = None,
-        AlarmNamePrefix: str = None,
-        AlarmTypes: Sequence[AlarmTypeType] = None,
-        ChildrenOfAlarmName: str = None,
-        ParentsOfAlarmName: str = None,
-        StateValue: StateValueType = None,
-        ActionPrefix: str = None,
-        MaxRecords: int = None,
-        NextToken: str = None
+        AlarmNames: Sequence[str] = ...,
+        AlarmNamePrefix: str = ...,
+        AlarmTypes: Sequence[AlarmTypeType] = ...,
+        ChildrenOfAlarmName: str = ...,
+        ParentsOfAlarmName: str = ...,
+        StateValue: StateValueType = ...,
+        ActionPrefix: str = ...,
+        MaxRecords: int = ...,
+        NextToken: str = ...
     ) -> DescribeAlarmsOutputTypeDef:
         """
         Retrieves the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarms)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarms)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#describe_alarms)
         """
 
@@ -214,42 +214,42 @@ class CloudWatchClient(BaseClient):
         *,
         MetricName: str,
         Namespace: str,
-        Statistic: StatisticType = None,
-        ExtendedStatistic: str = None,
-        Dimensions: Sequence["DimensionTypeDef"] = None,
-        Period: int = None,
-        Unit: StandardUnitType = None
+        Statistic: StatisticType = ...,
+        ExtendedStatistic: str = ...,
+        Dimensions: Sequence["DimensionTypeDef"] = ...,
+        Period: int = ...,
+        Unit: StandardUnitType = ...
     ) -> DescribeAlarmsForMetricOutputTypeDef:
         """
         Retrieves the alarms for the specified metric.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarms_for_metric)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.describe_alarms_for_metric)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#describe_alarms_for_metric)
         """
 
     def describe_anomaly_detectors(
         self,
         *,
-        NextToken: str = None,
-        MaxResults: int = None,
-        Namespace: str = None,
-        MetricName: str = None,
-        Dimensions: Sequence["DimensionTypeDef"] = None
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        Namespace: str = ...,
+        MetricName: str = ...,
+        Dimensions: Sequence["DimensionTypeDef"] = ...
     ) -> DescribeAnomalyDetectorsOutputTypeDef:
         """
         Lists the anomaly detection models that you have created in your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.describe_anomaly_detectors)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.describe_anomaly_detectors)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#describe_anomaly_detectors)
         """
 
     def describe_insight_rules(
-        self, *, NextToken: str = None, MaxResults: int = None
+        self, *, NextToken: str = ..., MaxResults: int = ...
     ) -> DescribeInsightRulesOutputTypeDef:
         """
         Returns a list of all the Contributor Insights rules in your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.describe_insight_rules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.describe_insight_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#describe_insight_rules)
         """
 
@@ -257,7 +257,7 @@ class CloudWatchClient(BaseClient):
         """
         Disables the actions for the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.disable_alarm_actions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.disable_alarm_actions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#disable_alarm_actions)
         """
 
@@ -267,7 +267,7 @@ class CloudWatchClient(BaseClient):
         """
         Disables the specified Contributor Insights rules.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.disable_insight_rules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.disable_insight_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#disable_insight_rules)
         """
 
@@ -275,7 +275,7 @@ class CloudWatchClient(BaseClient):
         """
         Enables the actions for the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.enable_alarm_actions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.enable_alarm_actions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#enable_alarm_actions)
         """
 
@@ -283,21 +283,21 @@ class CloudWatchClient(BaseClient):
         """
         Enables the specified Contributor Insights rules.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.enable_insight_rules)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.enable_insight_rules)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#enable_insight_rules)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#generate_presigned_url)
         """
 
@@ -305,7 +305,7 @@ class CloudWatchClient(BaseClient):
         """
         Displays the details of the dashboard that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.get_dashboard)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.get_dashboard)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_dashboard)
         """
 
@@ -316,15 +316,15 @@ class CloudWatchClient(BaseClient):
         StartTime: Union[datetime, str],
         EndTime: Union[datetime, str],
         Period: int,
-        MaxContributorCount: int = None,
-        Metrics: Sequence[str] = None,
-        OrderBy: str = None
+        MaxContributorCount: int = ...,
+        Metrics: Sequence[str] = ...,
+        OrderBy: str = ...
     ) -> GetInsightRuleReportOutputTypeDef:
         """
         This operation returns the time series data collected by a Contributor Insights
         rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.get_insight_rule_report)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.get_insight_rule_report)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_insight_rule_report)
         """
 
@@ -334,16 +334,16 @@ class CloudWatchClient(BaseClient):
         MetricDataQueries: Sequence["MetricDataQueryTypeDef"],
         StartTime: Union[datetime, str],
         EndTime: Union[datetime, str],
-        NextToken: str = None,
-        ScanBy: ScanByType = None,
-        MaxDatapoints: int = None,
-        LabelOptions: "LabelOptionsTypeDef" = None
+        NextToken: str = ...,
+        ScanBy: ScanByType = ...,
+        MaxDatapoints: int = ...,
+        LabelOptions: "LabelOptionsTypeDef" = ...
     ) -> GetMetricDataOutputTypeDef:
         """
         You can use the `GetMetricData` API to retrieve as many as 500 different metrics
         in a single request, with a total of as many as 100,800 data points.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_metric_data)
         """
 
@@ -355,15 +355,15 @@ class CloudWatchClient(BaseClient):
         StartTime: Union[datetime, str],
         EndTime: Union[datetime, str],
         Period: int,
-        Dimensions: Sequence["DimensionTypeDef"] = None,
-        Statistics: Sequence[StatisticType] = None,
-        ExtendedStatistics: Sequence[str] = None,
-        Unit: StandardUnitType = None
+        Dimensions: Sequence["DimensionTypeDef"] = ...,
+        Statistics: Sequence[StatisticType] = ...,
+        ExtendedStatistics: Sequence[str] = ...,
+        Unit: StandardUnitType = ...
     ) -> GetMetricStatisticsOutputTypeDef:
         """
         Gets statistics for the specified metric.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_statistics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_statistics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_metric_statistics)
         """
 
@@ -371,54 +371,54 @@ class CloudWatchClient(BaseClient):
         """
         Returns information about the metric stream that you specify.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_stream)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_stream)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_metric_stream)
         """
 
     def get_metric_widget_image(
-        self, *, MetricWidget: str, OutputFormat: str = None
+        self, *, MetricWidget: str, OutputFormat: str = ...
     ) -> GetMetricWidgetImageOutputTypeDef:
         """
         You can use the `GetMetricWidgetImage` API to retrieve a snapshot graph of one
         or more Amazon CloudWatch metrics as a bitmap image.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_widget_image)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_widget_image)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#get_metric_widget_image)
         """
 
     def list_dashboards(
-        self, *, DashboardNamePrefix: str = None, NextToken: str = None
+        self, *, DashboardNamePrefix: str = ..., NextToken: str = ...
     ) -> ListDashboardsOutputTypeDef:
         """
         Returns a list of the dashboards for your account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.list_dashboards)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.list_dashboards)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#list_dashboards)
         """
 
     def list_metric_streams(
-        self, *, NextToken: str = None, MaxResults: int = None
+        self, *, NextToken: str = ..., MaxResults: int = ...
     ) -> ListMetricStreamsOutputTypeDef:
         """
         Returns a list of metric streams in this account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.list_metric_streams)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.list_metric_streams)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#list_metric_streams)
         """
 
     def list_metrics(
         self,
         *,
-        Namespace: str = None,
-        MetricName: str = None,
-        Dimensions: Sequence["DimensionFilterTypeDef"] = None,
-        NextToken: str = None,
-        RecentlyActive: Literal["PT3H"] = None
+        Namespace: str = ...,
+        MetricName: str = ...,
+        Dimensions: Sequence["DimensionFilterTypeDef"] = ...,
+        NextToken: str = ...,
+        RecentlyActive: Literal["PT3H"] = ...
     ) -> ListMetricsOutputTypeDef:
         """
         List the specified metrics.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.list_metrics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.list_metrics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#list_metrics)
         """
 
@@ -426,7 +426,7 @@ class CloudWatchClient(BaseClient):
         """
         Displays the tags associated with a CloudWatch resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#list_tags_for_resource)
         """
 
@@ -436,13 +436,13 @@ class CloudWatchClient(BaseClient):
         Namespace: str,
         MetricName: str,
         Stat: str,
-        Dimensions: Sequence["DimensionTypeDef"] = None,
-        Configuration: "AnomalyDetectorConfigurationTypeDef" = None
+        Dimensions: Sequence["DimensionTypeDef"] = ...,
+        Configuration: "AnomalyDetectorConfigurationTypeDef" = ...
     ) -> Dict[str, Any]:
         """
         Creates an anomaly detection model for a CloudWatch metric.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.put_anomaly_detector)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.put_anomaly_detector)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_anomaly_detector)
         """
 
@@ -451,17 +451,17 @@ class CloudWatchClient(BaseClient):
         *,
         AlarmName: str,
         AlarmRule: str,
-        ActionsEnabled: bool = None,
-        AlarmActions: Sequence[str] = None,
-        AlarmDescription: str = None,
-        InsufficientDataActions: Sequence[str] = None,
-        OKActions: Sequence[str] = None,
-        Tags: Sequence["TagTypeDef"] = None
+        ActionsEnabled: bool = ...,
+        AlarmActions: Sequence[str] = ...,
+        AlarmDescription: str = ...,
+        InsufficientDataActions: Sequence[str] = ...,
+        OKActions: Sequence[str] = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> None:
         """
         Creates or updates a *composite alarm*.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.put_composite_alarm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.put_composite_alarm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_composite_alarm)
         """
 
@@ -470,7 +470,7 @@ class CloudWatchClient(BaseClient):
         Creates a dashboard if it does not already exist, or updates an existing
         dashboard.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.put_dashboard)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.put_dashboard)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_dashboard)
         """
 
@@ -479,13 +479,13 @@ class CloudWatchClient(BaseClient):
         *,
         RuleName: str,
         RuleDefinition: str,
-        RuleState: str = None,
-        Tags: Sequence["TagTypeDef"] = None
+        RuleState: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> Dict[str, Any]:
         """
         Creates a Contributor Insights rule.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.put_insight_rule)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.put_insight_rule)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_insight_rule)
         """
 
@@ -495,31 +495,31 @@ class CloudWatchClient(BaseClient):
         AlarmName: str,
         EvaluationPeriods: int,
         ComparisonOperator: ComparisonOperatorType,
-        AlarmDescription: str = None,
-        ActionsEnabled: bool = None,
-        OKActions: Sequence[str] = None,
-        AlarmActions: Sequence[str] = None,
-        InsufficientDataActions: Sequence[str] = None,
-        MetricName: str = None,
-        Namespace: str = None,
-        Statistic: StatisticType = None,
-        ExtendedStatistic: str = None,
-        Dimensions: Sequence["DimensionTypeDef"] = None,
-        Period: int = None,
-        Unit: StandardUnitType = None,
-        DatapointsToAlarm: int = None,
-        Threshold: float = None,
-        TreatMissingData: str = None,
-        EvaluateLowSampleCountPercentile: str = None,
-        Metrics: Sequence["MetricDataQueryTypeDef"] = None,
-        Tags: Sequence["TagTypeDef"] = None,
-        ThresholdMetricId: str = None
+        AlarmDescription: str = ...,
+        ActionsEnabled: bool = ...,
+        OKActions: Sequence[str] = ...,
+        AlarmActions: Sequence[str] = ...,
+        InsufficientDataActions: Sequence[str] = ...,
+        MetricName: str = ...,
+        Namespace: str = ...,
+        Statistic: StatisticType = ...,
+        ExtendedStatistic: str = ...,
+        Dimensions: Sequence["DimensionTypeDef"] = ...,
+        Period: int = ...,
+        Unit: StandardUnitType = ...,
+        DatapointsToAlarm: int = ...,
+        Threshold: float = ...,
+        TreatMissingData: str = ...,
+        EvaluateLowSampleCountPercentile: str = ...,
+        Metrics: Sequence["MetricDataQueryTypeDef"] = ...,
+        Tags: Sequence["TagTypeDef"] = ...,
+        ThresholdMetricId: str = ...
     ) -> None:
         """
         Creates or updates an alarm and associates it with the specified metric, metric
         math expression, or anomaly detection model.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_alarm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_alarm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_metric_alarm)
         """
 
@@ -529,7 +529,7 @@ class CloudWatchClient(BaseClient):
         """
         Publishes metric data points to Amazon CloudWatch.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_metric_data)
         """
 
@@ -540,14 +540,14 @@ class CloudWatchClient(BaseClient):
         FirehoseArn: str,
         RoleArn: str,
         OutputFormat: MetricStreamOutputFormatType,
-        IncludeFilters: Sequence["MetricStreamFilterTypeDef"] = None,
-        ExcludeFilters: Sequence["MetricStreamFilterTypeDef"] = None,
-        Tags: Sequence["TagTypeDef"] = None
+        IncludeFilters: Sequence["MetricStreamFilterTypeDef"] = ...,
+        ExcludeFilters: Sequence["MetricStreamFilterTypeDef"] = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> PutMetricStreamOutputTypeDef:
         """
         Creates or updates a metric stream.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_stream)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.put_metric_stream)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#put_metric_stream)
         """
 
@@ -557,12 +557,12 @@ class CloudWatchClient(BaseClient):
         AlarmName: str,
         StateValue: StateValueType,
         StateReason: str,
-        StateReasonData: str = None
+        StateReasonData: str = ...
     ) -> None:
         """
         Temporarily sets the state of an alarm for testing purposes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.set_alarm_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.set_alarm_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#set_alarm_state)
         """
 
@@ -570,7 +570,7 @@ class CloudWatchClient(BaseClient):
         """
         Starts the streaming of metrics for one or more of your metric streams.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.start_metric_streams)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.start_metric_streams)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#start_metric_streams)
         """
 
@@ -578,7 +578,7 @@ class CloudWatchClient(BaseClient):
         """
         Stops the streaming of metrics for one or more of your metric streams.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.stop_metric_streams)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.stop_metric_streams)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#stop_metric_streams)
         """
 
@@ -586,7 +586,7 @@ class CloudWatchClient(BaseClient):
         """
         Assigns one or more tags (key-value pairs) to the specified CloudWatch resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#tag_resource)
         """
 
@@ -594,7 +594,7 @@ class CloudWatchClient(BaseClient):
         """
         Removes one or more tags from the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client.html#untag_resource)
         """
 
@@ -603,42 +603,42 @@ class CloudWatchClient(BaseClient):
         self, operation_name: Literal["describe_alarm_history"]
     ) -> DescribeAlarmHistoryPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarmHistory)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#describealarmhistorypaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_alarms"]) -> DescribeAlarmsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Paginator.DescribeAlarms)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#describealarmspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_metric_data"]) -> GetMetricDataPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Paginator.GetMetricData)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#getmetricdatapaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_dashboards"]) -> ListDashboardsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Paginator.ListDashboards)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#listdashboardspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_metrics"]) -> ListMetricsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Paginator.ListMetrics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/paginators.html#listmetricspaginator)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["alarm_exists"]) -> AlarmExistsWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#alarmexistswaiter)
         """
 
@@ -647,6 +647,6 @@ class CloudWatchClient(BaseClient):
         self, waiter_name: Literal["composite_alarm_exists"]
     ) -> CompositeAlarmExistsWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#compositealarmexistswaiter)
         """
