@@ -62,7 +62,7 @@ __all__ = (
 
 class ServiceResourceAlarmsCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.ServiceResource.alarms)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.ServiceResource.alarms)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#serviceresourcealarmscollection)
     """
 
@@ -74,15 +74,15 @@ class ServiceResourceAlarmsCollection(ResourceCollection):
     def filter(  # type: ignore
         self,
         *,
-        AlarmNames: Sequence[str] = None,
-        AlarmNamePrefix: str = None,
-        AlarmTypes: Sequence[AlarmTypeType] = None,
-        ChildrenOfAlarmName: str = None,
-        ParentsOfAlarmName: str = None,
-        StateValue: StateValueType = None,
-        ActionPrefix: str = None,
-        MaxRecords: int = None,
-        NextToken: str = None
+        AlarmNames: Sequence[str] = ...,
+        AlarmNamePrefix: str = ...,
+        AlarmTypes: Sequence[AlarmTypeType] = ...,
+        ChildrenOfAlarmName: str = ...,
+        ParentsOfAlarmName: str = ...,
+        StateValue: StateValueType = ...,
+        ActionPrefix: str = ...,
+        MaxRecords: int = ...,
+        NextToken: str = ...
     ) -> "ServiceResourceAlarmsCollection":
         """
         Get items from the collection, passing keyword arguments along as parameters to the underlying service operation, which are typically used to filter the results.
@@ -126,7 +126,7 @@ class ServiceResourceAlarmsCollection(ResourceCollection):
 
 class ServiceResourceMetricsCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.ServiceResource.metrics)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.ServiceResource.metrics)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#serviceresourcemetricscollection)
     """
 
@@ -138,11 +138,11 @@ class ServiceResourceMetricsCollection(ResourceCollection):
     def filter(  # type: ignore
         self,
         *,
-        Namespace: str = None,
-        MetricName: str = None,
-        Dimensions: Sequence["DimensionFilterTypeDef"] = None,
-        NextToken: str = None,
-        RecentlyActive: Literal["PT3H"] = None
+        Namespace: str = ...,
+        MetricName: str = ...,
+        Dimensions: Sequence["DimensionFilterTypeDef"] = ...,
+        NextToken: str = ...,
+        RecentlyActive: Literal["PT3H"] = ...
     ) -> "ServiceResourceMetricsCollection":
         """
         Get items from the collection, passing keyword arguments along as parameters to the underlying service operation, which are typically used to filter the results.
@@ -171,7 +171,7 @@ class ServiceResourceMetricsCollection(ResourceCollection):
 
 class MetricAlarmsCollection(ResourceCollection):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Metric.alarms)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Metric.alarms)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricalarmscollection)
     """
 
@@ -183,11 +183,11 @@ class MetricAlarmsCollection(ResourceCollection):
     def filter(  # type: ignore
         self,
         *,
-        Statistic: StatisticType = None,
-        ExtendedStatistic: str = None,
-        Dimensions: Sequence["DimensionTypeDef"] = None,
-        Period: int = None,
-        Unit: StandardUnitType = None
+        Statistic: StatisticType = ...,
+        ExtendedStatistic: str = ...,
+        Dimensions: Sequence["DimensionTypeDef"] = ...,
+        Period: int = ...,
+        Unit: StandardUnitType = ...
     ) -> "MetricAlarmsCollection":
         """
         Get items from the collection, passing keyword arguments along as parameters to the underlying service operation, which are typically used to filter the results.
@@ -231,7 +231,7 @@ class MetricAlarmsCollection(ResourceCollection):
 
 class Alarm(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarm)
     """
 
@@ -269,25 +269,25 @@ class Alarm(Boto3ServiceResource):
         """
         Deletes the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Alarm.delete)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Alarm.delete)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmdelete-method)
         """
 
     def describe_history(
         self,
         *,
-        AlarmTypes: Sequence[AlarmTypeType] = None,
-        HistoryItemType: HistoryItemTypeType = None,
-        StartDate: Union[datetime, str] = None,
-        EndDate: Union[datetime, str] = None,
-        MaxRecords: int = None,
-        NextToken: str = None,
-        ScanBy: ScanByType = None
+        AlarmTypes: Sequence[AlarmTypeType] = ...,
+        HistoryItemType: HistoryItemTypeType = ...,
+        StartDate: Union[datetime, str] = ...,
+        EndDate: Union[datetime, str] = ...,
+        MaxRecords: int = ...,
+        NextToken: str = ...,
+        ScanBy: ScanByType = ...
     ) -> DescribeAlarmHistoryOutputTypeDef:
         """
         Retrieves the history for the specified alarm.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Alarm.describe_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Alarm.describe_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmdescribe_history-method)
         """
 
@@ -295,7 +295,7 @@ class Alarm(Boto3ServiceResource):
         """
         Disables the actions for the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Alarm.disable_actions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Alarm.disable_actions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmdisable_actions-method)
         """
 
@@ -303,7 +303,7 @@ class Alarm(Boto3ServiceResource):
         """
         Enables the actions for the specified alarms.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Alarm.enable_actions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Alarm.enable_actions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmenable_actions-method)
         """
 
@@ -311,7 +311,7 @@ class Alarm(Boto3ServiceResource):
         """
         Returns a list of all the available sub-resources for this Resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Alarm.get_available_subresources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Alarm.get_available_subresources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmget_available_subresources-method)
         """
 
@@ -320,7 +320,7 @@ class Alarm(Boto3ServiceResource):
         Calls :py:meth:`CloudWatch.Client.describe_alarms` to update the attributes of
         the Alarm resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Alarm.load)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Alarm.load)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmload-method)
         """
 
@@ -329,17 +329,17 @@ class Alarm(Boto3ServiceResource):
         Calls :py:meth:`CloudWatch.Client.describe_alarms` to update the attributes of
         the Alarm resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Alarm.reload)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Alarm.reload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmreload-method)
         """
 
     def set_state(
-        self, *, StateValue: StateValueType, StateReason: str, StateReasonData: str = None
+        self, *, StateValue: StateValueType, StateReason: str, StateReasonData: str = ...
     ) -> None:
         """
         Temporarily sets the state of an alarm for testing purposes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Alarm.set_state)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Alarm.set_state)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#alarmset_state-method)
         """
 
@@ -349,7 +349,7 @@ _Alarm = Alarm
 
 class Metric(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metric)
     """
 
@@ -363,7 +363,7 @@ class Metric(Boto3ServiceResource):
         """
         Returns a list of all the available sub-resources for this Resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Metric.get_available_subresources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Metric.get_available_subresources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricget_available_subresources-method)
         """
 
@@ -373,15 +373,15 @@ class Metric(Boto3ServiceResource):
         StartTime: Union[datetime, str],
         EndTime: Union[datetime, str],
         Period: int,
-        Dimensions: Sequence["DimensionTypeDef"] = None,
-        Statistics: Sequence[StatisticType] = None,
-        ExtendedStatistics: Sequence[str] = None,
-        Unit: StandardUnitType = None
+        Dimensions: Sequence["DimensionTypeDef"] = ...,
+        Statistics: Sequence[StatisticType] = ...,
+        ExtendedStatistics: Sequence[str] = ...,
+        Unit: StandardUnitType = ...
     ) -> GetMetricStatisticsOutputTypeDef:
         """
         Gets statistics for the specified metric.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Metric.get_statistics)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Metric.get_statistics)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricget_statistics-method)
         """
 
@@ -390,7 +390,7 @@ class Metric(Boto3ServiceResource):
         Calls :py:meth:`CloudWatch.Client.list_metrics` to update the attributes of the
         Metric resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Metric.load)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Metric.load)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricload-method)
         """
 
@@ -400,29 +400,29 @@ class Metric(Boto3ServiceResource):
         AlarmName: str,
         EvaluationPeriods: int,
         ComparisonOperator: ComparisonOperatorType,
-        AlarmDescription: str = None,
-        ActionsEnabled: bool = None,
-        OKActions: Sequence[str] = None,
-        AlarmActions: Sequence[str] = None,
-        InsufficientDataActions: Sequence[str] = None,
-        Statistic: StatisticType = None,
-        ExtendedStatistic: str = None,
-        Dimensions: Sequence["DimensionTypeDef"] = None,
-        Period: int = None,
-        Unit: StandardUnitType = None,
-        DatapointsToAlarm: int = None,
-        Threshold: float = None,
-        TreatMissingData: str = None,
-        EvaluateLowSampleCountPercentile: str = None,
-        Metrics: Sequence["MetricDataQueryTypeDef"] = None,
-        Tags: Sequence["TagTypeDef"] = None,
-        ThresholdMetricId: str = None
+        AlarmDescription: str = ...,
+        ActionsEnabled: bool = ...,
+        OKActions: Sequence[str] = ...,
+        AlarmActions: Sequence[str] = ...,
+        InsufficientDataActions: Sequence[str] = ...,
+        Statistic: StatisticType = ...,
+        ExtendedStatistic: str = ...,
+        Dimensions: Sequence["DimensionTypeDef"] = ...,
+        Period: int = ...,
+        Unit: StandardUnitType = ...,
+        DatapointsToAlarm: int = ...,
+        Threshold: float = ...,
+        TreatMissingData: str = ...,
+        EvaluateLowSampleCountPercentile: str = ...,
+        Metrics: Sequence["MetricDataQueryTypeDef"] = ...,
+        Tags: Sequence["TagTypeDef"] = ...,
+        ThresholdMetricId: str = ...
     ) -> _Alarm:
         """
         Creates or updates an alarm and associates it with the specified metric, metric
         math expression, or anomaly detection model.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Metric.put_alarm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Metric.put_alarm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricput_alarm-method)
         """
 
@@ -430,7 +430,7 @@ class Metric(Boto3ServiceResource):
         """
         Publishes metric data points to Amazon CloudWatch.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Metric.put_data)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Metric.put_data)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricput_data-method)
         """
 
@@ -439,7 +439,7 @@ class Metric(Boto3ServiceResource):
         Calls :py:meth:`CloudWatch.Client.list_metrics` to update the attributes of the
         Metric resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Metric.reload)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Metric.reload)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#metricreload-method)
         """
 
@@ -453,7 +453,7 @@ class CloudWatchResourceMeta(ResourceMeta):
 
 class CloudWatchServiceResource(Boto3ServiceResource):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.ServiceResource)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.ServiceResource)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html)
     """
 
@@ -465,7 +465,7 @@ class CloudWatchServiceResource(Boto3ServiceResource):
         """
         Creates a Alarm resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Alarm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#cloudwatchserviceresourcealarm-method)
         """
 
@@ -473,7 +473,7 @@ class CloudWatchServiceResource(Boto3ServiceResource):
         """
         Creates a Metric resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.ServiceResource.Metric)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#cloudwatchserviceresourcemetric-method)
         """
 
@@ -481,6 +481,6 @@ class CloudWatchServiceResource(Boto3ServiceResource):
         """
         Returns a list of all the available sub-resources for this Resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.ServiceResource.get_available_subresources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.ServiceResource.get_available_subresources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/service_resource.html#cloudwatchserviceresourceget_available_subresources-method)
         """
