@@ -32,51 +32,51 @@ __all__ = ("AlarmExistsWaiter", "CompositeAlarmExistsWaiter")
 
 class AlarmExistsWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#alarmexistswaiter)
     """
 
     def wait(
         self,
         *,
-        AlarmNames: Sequence[str] = None,
-        AlarmNamePrefix: str = None,
-        AlarmTypes: Sequence[AlarmTypeType] = None,
-        ChildrenOfAlarmName: str = None,
-        ParentsOfAlarmName: str = None,
-        StateValue: StateValueType = None,
-        ActionPrefix: str = None,
-        MaxRecords: int = None,
-        NextToken: str = None,
-        WaiterConfig: WaiterConfigTypeDef = None
+        AlarmNames: Sequence[str] = ...,
+        AlarmNamePrefix: str = ...,
+        AlarmTypes: Sequence[AlarmTypeType] = ...,
+        ChildrenOfAlarmName: str = ...,
+        ParentsOfAlarmName: str = ...,
+        StateValue: StateValueType = ...,
+        ActionPrefix: str = ...,
+        MaxRecords: int = ...,
+        NextToken: str = ...,
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Waiter.AlarmExists.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#alarmexistswaiter)
         """
 
 
 class CompositeAlarmExistsWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#compositealarmexistswaiter)
     """
 
     def wait(
         self,
         *,
-        AlarmNames: Sequence[str] = None,
-        AlarmNamePrefix: str = None,
-        AlarmTypes: Sequence[AlarmTypeType] = None,
-        ChildrenOfAlarmName: str = None,
-        ParentsOfAlarmName: str = None,
-        StateValue: StateValueType = None,
-        ActionPrefix: str = None,
-        MaxRecords: int = None,
-        NextToken: str = None,
-        WaiterConfig: WaiterConfigTypeDef = None
+        AlarmNames: Sequence[str] = ...,
+        AlarmNamePrefix: str = ...,
+        AlarmTypes: Sequence[AlarmTypeType] = ...,
+        ChildrenOfAlarmName: str = ...,
+        ParentsOfAlarmName: str = ...,
+        StateValue: StateValueType = ...,
+        ActionPrefix: str = ...,
+        MaxRecords: int = ...,
+        NextToken: str = ...,
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/cloudwatch.html#CloudWatch.Waiter.CompositeAlarmExists.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/waiters.html#compositealarmexistswaiter)
         """
